@@ -31,7 +31,7 @@ class SingularClient(object):
         retry = Retry(
             connect=5,
             backoff_factor=0.5,
-            status_forcelist=(500, 502, 504),
+            status_forcelist=(500, 502, 503, 504),
             method_whitelist=('GET', 'POST')
         )
         adapter = HTTPAdapter(max_retries=retry)
@@ -141,7 +141,7 @@ class SingularClient(object):
                                         dimensions=(Dimensions.APP, Dimensions.SOURCE,
                                                     Dimensions.SKAN_CAMPAIGN_ID, Dimensions.SKAN_CONVERSION_VALUE),
                                         metrics=(Metrics.SKAN_INSTALLS,),
-                                        discrepancy_metrics=None,
+                                        discrepancy_metrics=[],
                                         source=None,
                                         app=None,
                                         time_breakdown=TimeBreakdown.ALL,
@@ -372,7 +372,7 @@ class SingularClient(object):
     @classmethod
     def _build_skan_reporting_query(cls, start_date, end_date, format, dimensions, metrics, app, source, time_breakdown,
                                     country_code_format, filters, skadnetwork_date_type, skan_events,
-                                    discrepancy_metrics=None,
+                                    discrepancy_metrics=[],
                                     **kwargs):
         query_dict = cls._build_reporting_query(start_date, end_date, format, dimensions, metrics, discrepancy_metrics,
                                                 None, None, app, source, None, time_breakdown,
